@@ -23,6 +23,7 @@ fi
 # coverage erase will not erase the files from --parallel-mode
 rm -f $TESTS_DIR/.coverage*
 
+./setup.py build
 # run with xvfb and coverage
 
 XVFB_CMDLINE=""
@@ -104,3 +105,4 @@ else
         echo "All OK!"
     fi
 fi
+./setup.py clean
