@@ -26,19 +26,20 @@ import traceback
 from subprocess import (
     Popen,
     PIPE,
-    )
+)
 
-from gi.repository import GObject
+from gi.repository import GObject, GLib
 
-from softwarecenter.utils import (sources_filename_from_ppa_entry,
-                                  release_filename_in_lists_from_deb_line,
-                                  obfuscate_private_ppa_details,
-                                  utf8,
-                                  )
+from softwarecenter.utils import (
+    sources_filename_from_ppa_entry,
+    release_filename_in_lists_from_deb_line,
+    obfuscate_private_ppa_details,
+    utf8,
+)
 from softwarecenter.enums import (
     TransactionTypes,
     PURCHASE_TRANSACTION_ID,
-    )
+)
 from softwarecenter.paths import APPORT_RECOVERABLE_ERROR
 
 from aptdaemon import client
@@ -54,7 +55,8 @@ from softwarecenter.backend.transactionswatcher import (
     BaseTransactionsWatcher,
     BaseTransaction,
     TransactionFinishedResult,
-    TransactionProgress)
+    TransactionProgress,
+)
 from softwarecenter.backend.installbackend import InstallBackend
 
 from gettext import gettext as _
@@ -171,7 +173,7 @@ class AptdaemonTransactionsWatcher(BaseTransactionsWatcher):
         self.emit("lowlevel-transactions-changed", current, queued)
 
     def get_transaction(self, tid):
-        """ synchroneously return a transaction """
+        """ synchronously return a transaction """
         try:
             trans = client.get_transaction(tid)
             return AptdaemonTransaction(trans)
@@ -283,7 +285,7 @@ class AptdaemonBackend(GObject.GObject, InstallBackend):
     # FIXME: upgrade add-ons here
     @inline_callbacks
     def upgrade(self, app, iconname, addons_install=[], addons_remove=[],
-        metadata=None):
+                metadata=None):
         """ upgrade a single package """
         pkgname = app.pkgname
         appname = app.appname
@@ -326,7 +328,7 @@ class AptdaemonBackend(GObject.GObject, InstallBackend):
 
     @inline_callbacks
     def remove(self, app, iconname, addons_install=[], addons_remove=[],
-        metadata=None):
+               metadata=None):
         """ remove a single package """
         pkgname = app.pkgname
         appname = app.appname
@@ -343,7 +345,7 @@ class AptdaemonBackend(GObject.GObject, InstallBackend):
 
     @inline_callbacks
     def remove_multiple(self, apps, iconnames, addons_install=[],
-        addons_remove=[], metadatas=None):
+                        addons_remove=[], metadatas=None):
         """ queue a list of packages for removal  """
         if metadatas is None:
             metadatas = []
@@ -354,7 +356,7 @@ class AptdaemonBackend(GObject.GObject, InstallBackend):
 
     @inline_callbacks
     def install(self, app, iconname, filename=None, addons_install=[],
-        addons_remove=[], metadata=None, force=False):
+                addons_remove=[], metadata=None, force=False):
         """Install a single package from the archive
            If filename is given a local deb package is installed instead.
         """
@@ -388,7 +390,7 @@ class AptdaemonBackend(GObject.GObject, InstallBackend):
 
     @inline_callbacks
     def install_multiple(self, apps, iconnames, addons_install=[],
-        addons_remove=[], metadatas=None):
+                         addons_remove=[], metadatas=None):
         """ queue a list of packages for install  """
         if metadatas is None:
             metadatas = []
@@ -399,7 +401,7 @@ class AptdaemonBackend(GObject.GObject, InstallBackend):
 
     @inline_callbacks
     def apply_changes(self, app, iconname, addons_install=[],
-        addons_remove=[], metadata=None):
+                      addons_remove=[], metadata=None):
         """ install and remove add-ons """
         pkgname = app.pkgname
         appname = app.appname
@@ -428,7 +430,7 @@ class AptdaemonBackend(GObject.GObject, InstallBackend):
         d = apt_pkg.config.find_dir("Dir::Etc::sourceparts")
         trans = None
         if (not sources_list or
-            not os.path.exists(os.path.join(d, sources_list))):
+                not os.path.exists(os.path.join(d, sources_list))):
             sources_list = ""
         try:
             trans = yield self.aptd_client.update_cache(
@@ -445,7 +447,7 @@ class AptdaemonBackend(GObject.GObject, InstallBackend):
         trans = None
         try:
             trans = yield self.aptd_client.enable_distro_component(component)
-            # don't use self._run_transaction() here, to avoid sending uneeded
+            # don't use self._run_transaction() here, to avoid sending unneeded
             # signals
             yield trans.run(defer=True)
         except Exception as error:
@@ -472,13 +474,14 @@ class AptdaemonBackend(GObject.GObject, InstallBackend):
                 trans = yield self.aptd_client.add_vendor_key_from_file(
                     keyfile, wait=True)
                 # don't use self._run_transaction() here, to avoid sending
-                # uneeded signals
+                # unneeded signals
                 yield trans.run(defer=True)
         yield self.reload(sourcepart)
 
     @inline_callbacks
     def add_vendor_key_from_keyserver(self, keyid,
-        keyserver="hkp://keyserver.ubuntu.com:80/", metadata=None):
+                                  keyserver="hkp://keyserver.ubuntu.com:80/",
+                                  metadata=None):
         # strip the keysize
         if "/" in keyid:
             keyid = keyid.split("/")[1]
@@ -528,7 +531,7 @@ class AptdaemonBackend(GObject.GObject, InstallBackend):
 
     @inline_callbacks
     def add_license_key(self, license_key, license_key_path,
-        license_key_oauth, pkgname):
+                        license_key_oauth, pkgname):
         """ add a license key for a purchase. """
         self._logger.debug(
             "adding license_key for pkg '%s' of len: %i" % (
@@ -628,7 +631,7 @@ class AptdaemonBackend(GObject.GObject, InstallBackend):
 
     @inline_callbacks
     def _reload_for_commercial_repo_defer(self, app, trans_metadata,
-        sources_list):
+                                          sources_list):
         """
         helper that reloads and registers a callback for when the reload is
         finished
@@ -657,7 +660,8 @@ class AptdaemonBackend(GObject.GObject, InstallBackend):
 
     @inline_callbacks
     def _on_reload_for_add_repo_and_install_app_finished(self, backend, trans,
-        result, metadata, app):
+                                                         result, metadata,
+                                                         app):
         """
         callback that is called once after reload was queued
         and will trigger the install of the for-pay package itself
@@ -671,7 +675,7 @@ class AptdaemonBackend(GObject.GObject, InstallBackend):
         # check if this is the transaction we waiting for
         key = "sc_add_repo_and_install_pkgname"
         if not (key in trans.meta_data and
-            trans.meta_data[key] == app.pkgname):
+                trans.meta_data[key] == app.pkgname):
             return_value(None)
 
         # get the debline and check if we have a release.gpg file
@@ -744,7 +748,7 @@ class AptdaemonBackend(GObject.GObject, InstallBackend):
             trans.meta_data["sc_add_repo_and_install_try"] = str(retry + 1)
             sourcepart = trans.meta_data[
                 "sc_add_repo_and_install_sources_list"]
-            GObject.timeout_add_seconds(30, self._reload_for_commercial_repo,
+            GLib.timeout_add_seconds(30, self._reload_for_commercial_repo,
                                      app, trans.meta_data, sourcepart)
 
     # internal helpers
@@ -752,7 +756,7 @@ class AptdaemonBackend(GObject.GObject, InstallBackend):
         # cleanup progress signal (to be sure to not leave dbus
         # matchers around)
         if self._progress_signal:
-            GObject.source_remove(self._progress_signal)
+            GLib.source_remove(self._progress_signal)
             self._progress_signal = None
         # attach progress-changed signal for current transaction
         if current:
@@ -791,7 +795,7 @@ class AptdaemonBackend(GObject.GObject, InstallBackend):
         ensures that the fake transactions are considered and emits
         transactions-changed signal with the right pending transactions
         """
-        # inject a bunch FakePurchaseTransaction into the transations dict
+        # inject a bunch of FakePurchaseTransaction into the transactions dict
         for pkgname in self.pending_purchases:
             self.pending_transactions[pkgname] = \
                 self.pending_purchases[pkgname]
@@ -823,10 +827,10 @@ class AptdaemonBackend(GObject.GObject, InstallBackend):
         cleaned_error_details = obfuscate_private_ppa_details(
             trans.error_details)
         msg = utf8("%s: %s\n%s\n\n%s") % (
-              utf8(_("Error")),
-              utf8(enums.get_error_string_from_enum(trans.error_code)),
-              utf8(enums.get_error_description_from_enum(trans.error_code)),
-              utf8(cleaned_error_details))
+            utf8(_("Error")),
+            utf8(enums.get_error_string_from_enum(trans.error_code)),
+            utf8(enums.get_error_description_from_enum(trans.error_code)),
+            utf8(cleaned_error_details))
         self._logger.error("error in _on_trans_finished '%s'" % msg)
         # show dialog to the user and exit (no need to reopen the cache)
         if not trans.error_code:
@@ -874,7 +878,7 @@ class AptdaemonBackend(GObject.GObject, InstallBackend):
         if enum == enums.EXIT_FAILED:
             # Handle invalid packages separately
             if (trans.error and
-                trans.error.code == enums.ERROR_INVALID_PACKAGE_FILE):
+                    trans.error.code == enums.ERROR_INVALID_PACKAGE_FILE):
                 action = _("_Ignore and install")
                 res = self._show_transaction_failed_dialog(
                     trans, enum, action)
@@ -886,7 +890,7 @@ class AptdaemonBackend(GObject.GObject, InstallBackend):
                                  metadata=meta_copy, force=True)
                     return
             # on unauthenticated errors, try a "repair" using the
-            # reload functionatlity
+            # reload functionality
             elif (trans.error and
                   trans.error.code == enums.ERROR_PACKAGE_UNAUTHENTICATED):
                 action = _("Repair")
@@ -1010,7 +1014,11 @@ class AptdaemonBackend(GObject.GObject, InstallBackend):
 
         # calculate a dupes_signature here to have different buckets
         # on errors.ubuntu.com for the different crash types
-        dupes_signature = "software-center:trans-failed:%s" % trans.error_code
+        if trans:
+            error_code = trans.error_code
+        else:
+            error_code = "no-transaction"
+        dupes_signature = "software-center:trans-failed:%s" % error_code
 
         self.emit("transaction-stopped", result)
         if isinstance(error, dbus.DBusException):
@@ -1036,9 +1044,9 @@ class AptdaemonBackend(GObject.GObject, InstallBackend):
                 return
 
         # lintian errors are ignored and not send to apport_recoverable_error
-        # and dpkg errors as well as they will already be recorded seperately
+        # and dpkg errors as well as they will already be recorded separately
         # by apt itself
-        if trans.error_code in (enums.ERROR_INVALID_PACKAGE_FILE,
+        if error_code in (enums.ERROR_INVALID_PACKAGE_FILE,
                                 enums.ERROR_PACKAGE_MANAGER_FAILED):
             return
 
@@ -1050,9 +1058,9 @@ class AptdaemonBackend(GObject.GObject, InstallBackend):
             dupes_signature)
 
     def _call_apport_recoverable_error(self, text, error, dupes_signature):
-        """Call apports recoverable_problem dialog """
+        """Call apport's recoverable_problem dialog """
 
-        # ensure we have a proper expection string in the report
+        # ensure we have a proper exception string in the report
         if isinstance(error, Exception):
             error = traceback.format_exc(error)
 
@@ -1067,7 +1075,7 @@ class AptdaemonBackend(GObject.GObject, InstallBackend):
                 })
         # This will be quick as it just writes the report file. Then
         # the report gets picked up asynchronously by a inotify watch
-        # and displayed to the user in a seperate process.
+        # and displayed to the user in a separate process.
         p = Popen(
             [APPORT_RECOVERABLE_ERROR], stdin=PIPE, stdout=PIPE, stderr=PIPE)
 
