@@ -237,9 +237,10 @@ class PackagekitInfo(PackageInfo):
         if not p:
             return []
         autoremove = False
-        res = self.client.simulate_remove_packages((p.get_id(),),
-                                            autoremove, None,
-                                            self._on_progress_changed, None,
+        res = self.client.simulate_remove_packages(
+            (p.get_id(),),
+            autoremove, None,
+            self._on_progress_changed, None,
         )
         if not res:
             return []
@@ -253,9 +254,10 @@ class PackagekitInfo(PackageInfo):
         p = self._get_one_package(pkg.name)
         if not p:
             return []
-        res = self.client.simulate_install_packages((p.get_id(),),
-                                            None,
-                                            self._on_progress_changed, None,
+        res = self.client.simulate_install_packages(
+            (p.get_id(),),
+            None,
+            self._on_progress_changed, None,
         )
         if not res:
             return []
@@ -265,8 +267,9 @@ class PackagekitInfo(PackageInfo):
                 and p.get_info() == packagekit.InfoEnum.INSTALLED]
 
     def query_total_size_on_install(self, pkgname,
-                                  addons_install=None, addons_remove=None,
-                                  archive_suite=None):
+                                    addons_install=None,
+                                    addons_remove=None,
+                                    archive_suite=None):
         """ emit query-total-size-on-install-done signal
         with disk size in KB calculated for pkgname installation
         plus addons change.
@@ -314,7 +317,7 @@ class PackagekitInfo(PackageInfo):
         return pkgs[0]
 
     def _get_one_package(self, pkgname, pfilter=packagekit.FilterEnum.NONE,
-        cache=USE_CACHE):
+                         cache=USE_CACHE):
         LOG.debug("package_one %s", pkgname)  # , self._cache.keys()
         if (pkgname in self._cache.keys()) and cache:
             return self._cache[pkgname]
@@ -331,16 +334,17 @@ class PackagekitInfo(PackageInfo):
     def _get_packages(self, pkgname, pfilter=packagekit.FilterEnum.NONE):
         """ resolve a package name into a PkPackage object or return None """
         pfilter = 1 << pfilter
-        result = self.client.resolve(pfilter,
-                                     (pkgname,),
-                                     None,
-                                     self._on_progress_changed, None
+        result = self.client.resolve(
+            pfilter,
+            (pkgname,),
+            None,
+            self._on_progress_changed, None
         )
         pkgs = result.get_package_array()
         return pkgs
 
     def _get_repolist(self, pfilter=packagekit.FilterEnum.NONE,
-        cache=USE_CACHE):
+                      cache=USE_CACHE):
         """ obtain and cache a dictionary of repositories """
         if self._repocache:
             return self._repocache
