@@ -417,20 +417,28 @@ class AppInfoParserBase(object):
             region = get_region_cached()
             if region:
                 countrycode = region["countrycode"].lower()
-                # blacklist
-                if "%s%s" % (REGION_BLACKLIST_TAG, countrycode) in tags:
+                blacklist = [t.replace(REGION_BLACKLIST_TAG, "")
+                             for t in tags if
+                             t.startswith(REGION_BLACKLIST_TAG)]
+                whitelist = [t.replace(REGION_WHITELIST_TAG, "")
+                             for t in tags if
+                             t.startswith(REGION_WHITELIST_TAG)]
+
+                if countrycode in blacklist:
+                    if countrycode in whitelist:
+                        LOG.debug("%r.make_doc: %r black AND whitelisted for "
+                                  "region %r. Treating as blacklisted.", 
+                                  self.__class__.__name__, name, countrycode)
+                        
                     LOG.debug("%r.make_doc: skipping region restricted app %r "
                              "(blacklisted)", self.__class__.__name__, name)
                     return
-                # whitelist
-                for tag in tags:
-                    s = "%s%s" % (REGION_WHITELIST_TAG, countrycode)
-                    if (tag.startswith(REGION_WHITELIST_TAG) and not
-                            s in tag):
-                        LOG.debug("%r.make_doc: skipping region restricted "
-                                 "app %r (region not whitelisted)",
-                                 self.__class__.__name__, name)
-                        return
+
+                if len(whitelist) > 0 and countrycode not in whitelist:
+                    LOG.debug("%r.make_doc: skipping region restricted "
+                              "app %r (region not whitelisted)",
+                              self.__class__.__name__, name)
+                    return
 
         # popcon
         # FIXME: popularity not only based on popcon but also
