@@ -38,10 +38,10 @@ class Distro(object):
 
     # base path for the review summary, the JS will append %i.png
     # (with i={1,5})
-    REVIEW_SUMMARY_STARS_BASE_PATH = ("/usr/share/software-center/images/"
-        "review-summary")
+    REVIEW_SUMMARY_STARS_BASE_PATH = \
+        "/usr/share/software-center/images/review-summary"
     REVIEWS_SERVER = (os.environ.get("SOFTWARE_CENTER_REVIEWS_HOST") or
-        "http://localhost:8000")
+                      "http://localhost:8000")
 
     # You need to set this var to enable purchases
     PURCHASE_APP_URL = ""
@@ -64,7 +64,7 @@ class Distro(object):
         The description of the application displayed in the about dialog
         """
         return _("Lets you choose from thousands of applications available "
-            "for your system.")
+                 "for your system.")
 
     def get_distro_channel_name(self):
         """ The name of the main channel in the Release file (e.g. Ubuntu)"""
@@ -87,7 +87,7 @@ class Distro(object):
         return self._distro_code_name
 
     def get_maintenance_status(self, cache, appname, pkgname, component,
-        channelname):
+                               channelname):
         raise UnimplementedError
 
     def get_license_text(self, component):
@@ -110,16 +110,17 @@ class Distro(object):
 
     def get_install_warning_text(self, cache, pkg, appname, depends):
         primary = (utf8(_("To install %s, these items must be removed:")) %
-            utf8(appname))
+                   utf8(appname))
         button_text = _("Install Anyway")
 
         # alter it if a meta-package is affected
         for m in depends:
             if cache[m].section == "metapackages":
-                primary = utf8(_("If you install %s, future updates will not "
-                                 "include new items in <b>%s</b> set. "
-                                 "Are you sure you want to continue?")) % (
-                                 utf8(appname), cache[m].installed.summary)
+                primary = utf8(
+                    _("If you install %s, future updates will not "
+                      "include new items in <b>%s</b> set. "
+                      "Are you sure you want to continue?")) % (
+                          utf8(appname), cache[m].installed.summary)
                 button_text = _("Install Anyway")
                 depends = []
                 break
@@ -170,7 +171,7 @@ def _get_distro():
     distro_class_name = distro_id.capitalize()
     # start with a import, this gives us only a softwarecenter module
     module = __import__(distro_module_name, globals(), locals(), [], -1)
-    # get the right class and instanciate it
+    # get the right class and instantiate it
     distro_class = getattr(module, distro_class_name)
     instance = distro_class()
     return instance
@@ -193,7 +194,7 @@ def get_current_arch():
 def get_foreign_architectures():
     return get_distro().get_foreign_architectures()
 
-# singelton
+# singleton
 distro_instance = _get_distro()
 
 
