@@ -106,7 +106,7 @@ CA_CERT_FILE = '/etc/ssl/certs/ca-certificates.crt'
 
 
 def log_call(f):
-    """Decorator to log call funtions."""
+    """Decorator to log call functions."""
 
     @wraps(f)
     def inner(*args, **kwargs):
@@ -140,7 +140,7 @@ def get_data_file(*args):
 
 
 class LabeledEntry(Gtk.Entry):
-    """An entry that displays the label within itself ina grey color."""
+    """An entry that displays the label within itself in a grey color."""
 
     # Use of super on an old style class
     # pylint: disable=E1002
@@ -289,31 +289,31 @@ class UbuntuSSOClientGUI(object):
 
         self._signals = {
             'CaptchaGenerated':
-             self._filter_by_app_name(self.on_captcha_generated),
+                self._filter_by_app_name(self.on_captcha_generated),
             'CaptchaGenerationError':
-             self._filter_by_app_name(self.on_captcha_generation_error),
+                self._filter_by_app_name(self.on_captcha_generation_error),
             'UserRegistered':
-             self._filter_by_app_name(self.on_user_registered),
+                self._filter_by_app_name(self.on_user_registered),
             'UserRegistrationError':
-             self._filter_by_app_name(self.on_user_registration_error),
+                self._filter_by_app_name(self.on_user_registration_error),
             'EmailValidated':
-             self._filter_by_app_name(self.on_email_validated),
+                self._filter_by_app_name(self.on_email_validated),
             'EmailValidationError':
-             self._filter_by_app_name(self.on_email_validation_error),
+                self._filter_by_app_name(self.on_email_validation_error),
             'LoggedIn':
-             self._filter_by_app_name(self.on_logged_in),
+                self._filter_by_app_name(self.on_logged_in),
             'LoginError':
-             self._filter_by_app_name(self.on_login_error),
+                self._filter_by_app_name(self.on_login_error),
             'UserNotValidated':
-             self._filter_by_app_name(self.on_user_not_validated),
+                self._filter_by_app_name(self.on_user_not_validated),
             'PasswordResetTokenSent':
-             self._filter_by_app_name(self.on_password_reset_token_sent),
+                self._filter_by_app_name(self.on_password_reset_token_sent),
             'PasswordResetError':
-             self._filter_by_app_name(self.on_password_reset_error),
+                self._filter_by_app_name(self.on_password_reset_error),
             'PasswordChanged':
-             self._filter_by_app_name(self.on_password_changed),
+                self._filter_by_app_name(self.on_password_changed),
             'PasswordChangeError':
-             self._filter_by_app_name(self.on_password_change_error),
+                self._filter_by_app_name(self.on_password_change_error),
         }
 
         if window_id != 0:
@@ -363,7 +363,7 @@ class UbuntuSSOClientGUI(object):
     # helpers
 
     def _filter_by_app_name(self, f):
-        """Excecute the decorated function only for 'self.app_name'."""
+        """Execute the decorated function only for 'self.app_name'."""
 
         @wraps(f)
         def inner(app_name, *args, **kwargs):
@@ -701,12 +701,12 @@ class UbuntuSSOClientGUI(object):
         self.window.connect(signal_name, handler, *args, **kwargs)
 
     def finish_success(self):
-        """The whole process was completed succesfully. Show success page."""
+        """The whole process was completed successfully. Show success page."""
         self._done = True
         self._set_current_page(self.success_vbox)
 
     def finish_error(self):
-        """The whole process was not completed succesfully. Show error page."""
+        """The whole process wasn't completed successfully. Show error page."""
         self._done = True
         self._set_current_page(self.error_vbox)
 
