@@ -15,9 +15,10 @@ CAPTCHA_SOLUTION = u'william Byrd ñandú'
 EMAIL = u'test@example.com'
 EMAIL_TOKEN = u'B2P☺ gtf'
 HELP_TEXT = u'☛ Lorem ipsum dolor sit amet, consectetur adipiscing elit. ' \
-'Nam sed lorem nibh. Suspendisse gravida nulla non nunc suscipit pulvinar ' \
-'tempus ut augue. Morbi consequat, ligula a elementum pretium, ' \
-'dolor nulla tempus metus, sed viverra nisi risus non velit.'
+    'Nam sed lorem nibh. Suspendisse gravida nulla non nunc suscipit ' \
+    'pulvinar ' \
+    'tempus ut augue. Morbi consequat, ligula a elementum pretium, ' \
+    'dolor nulla tempus metus, sed viverra nisi risus non velit.'
 NAME = u'Juanito ☀ Pérez'
 PASSWORD = u'h3lloWorld☑ '
 PING_URL = u'http://localhost/ping-me/'
