@@ -596,6 +596,18 @@ class AppDetailsSCAApplicationParser(unittest.TestCase):
         # as the partner channel
         self.assertEqual(app_details.date_published, "2012-01-21 02:15:10")
 
+    @patch("softwarecenter.db.update.get_region_cached")
+    def test_no_region_tags_passes(self, get_region_cached_mock):
+        """Do not skip apps with no white or blacklist tags."""
+        get_region_cached_mock.return_value = { "countrycode" : "es",
+                                              }
+        app_dict = make_software_center_agent_app_dict({
+                "debtags": []})
+        item = PistonResponseObject.from_dict(app_dict)
+        parser = SCAApplicationParser(item)
+        doc = parser.make_doc(self.db._aptcache)
+        self.assertNotEqual(doc, None)
+
     @patch("softwarecenter.db.update.get_region_cached")
     def test_region_blacklist(self, get_region_cached_mock):
         """Test that the region blacklist ignores blacklisted locations"""
@@ -626,7 +638,9 @@ class AppDetailsSCAApplicationParser(unittest.TestCase):
         get_region_cached_mock.return_value = { "countrycode" : "es",
                                               }
         app_dict = make_software_center_agent_app_dict({
-                "debtags": ["%s%s" % (REGION_WHITELIST_TAG, "ES")]})
+                "debtags": ["%s%s" % (REGION_WHITELIST_TAG, "ES"),
+                            "%s%s" % (REGION_BLACKLIST_TAG, "CA"),
+                            "%s%s" % (REGION_WHITELIST_TAG, "US")]})
         item = PistonResponseObject.from_dict(app_dict)
         parser = SCAApplicationParser(item)
         doc = parser.make_doc(self.db._aptcache)
@@ -638,7 +652,25 @@ class AppDetailsSCAApplicationParser(unittest.TestCase):
         get_region_cached_mock.return_value = { "countrycode" : "de",
                                               }
         app_dict = make_software_center_agent_app_dict({
-                "debtags": ["%s%s" % (REGION_WHITELIST_TAG, "ES")]})
+                "debtags": ["%s%s" % (REGION_WHITELIST_TAG, "ES"),
+                            "%s%s" % (REGION_BLACKLIST_TAG, "CA"),
+                            "%s%s" % (REGION_WHITELIST_TAG, "US")]})
+        # see _get_app_details_from_app_dict
+        item = PistonResponseObject.from_dict(app_dict)
+        parser = SCAApplicationParser(item)
+        doc = parser.make_doc(self.db._aptcache)
+        self.assertEqual(doc, None)
+
+    @patch("softwarecenter.db.update.get_region_cached")
+    def test_region_whiteandblack_blacklists(self, get_region_cached_mock):
+        """Ignore regions that are in both black and whitelists."""
+        get_region_cached_mock.return_value = { "countrycode" : "de",
+                                              }
+        app_dict = make_software_center_agent_app_dict({
+                "debtags": ["%s%s" % (REGION_WHITELIST_TAG, "DE"),
+                            "%s%s" % (REGION_BLACKLIST_TAG, "DE"),
+                            "%s%s" % (REGION_BLACKLIST_TAG, "US"),
+                            "%s%s" % (REGION_WHITELIST_TAG, "ES")]})
         # see _get_app_details_from_app_dict
         item = PistonResponseObject.from_dict(app_dict)
         parser = SCAApplicationParser(item)
